@@ -4,11 +4,12 @@ from pathlib import Path
 from typing import Sequence, Union
 
 import rawpy
-from PySide6.QtCore import QFile, QIODevice, Qt, QDir, QFileInfo, QModelIndex
+from PySide6.QtCore import QFile, QIODevice, QDir, QFileInfo, QModelIndex
 from PySide6.QtGui import QPixmap, QScreen, QIcon
 from PySide6.QtUiTools import QUiLoader
-from PySide6.QtWidgets import QApplication, QLabel, QGraphicsScene, QFileDialog, QFileSystemModel, QListView, \
-    QFileIconProvider
+from PySide6.QtWidgets import (
+    QApplication, QGraphicsScene, QFileDialog, QFileSystemModel, QListView, QFileIconProvider
+)
 
 
 def get_parsed_args():
@@ -63,12 +64,12 @@ class RawIconProvider(QFileIconProvider):
                     thumb_pixmap = thumb_pixmap.scaledToWidth(80)
 
                     f = QFile(thumbnail_path)
-                    f.open(QIODevice.WriteOnly)
+                    f.open(QIODevice.OpenModeFlag.WriteOnly)
                     thumb_pixmap.save(f, 'PNG')
 
                 return QIcon(thumb_pixmap)
 
-            return super().icon(self.File)
+            return super().icon(self.IconType.File)
 
 
 class MainWindow:
@@ -77,7 +78,7 @@ class MainWindow:
         ui_file_name = 'main_window.ui'
         ui_file = QFile(Path(__file__).resolve().parent / ui_file_name)
 
-        if not ui_file.open(QIODevice.ReadOnly):
+        if not ui_file.open(QIODevice.OpenModeFlag.ReadOnly):
             print(f'Cannot open {ui_file_name}: {ui_file.errorString()}')
             sys.exit(-1)
 
@@ -97,8 +98,7 @@ class MainWindow:
             sys.exit(-1)
 
         self.window.thumbnail_list_view.clicked.connect(self.on_file_selected)
-
-        self.window.show()
+        self.window.showMaximized()
 
     def browse_directory(self):
         path = QFileDialog.getExistingDirectory(self.window, 'Select dataset directory', str(self.data_root_path),
@@ -113,10 +113,8 @@ class MainWindow:
         thumb_pixmap = QPixmap()
         thumb_pixmap.loadFromData(thumb.data)
 
-        image_label = QLabel()
-        image_label.setPixmap(thumb_pixmap)
         scene = QGraphicsScene()
-        scene.addWidget(image_label)
+        scene.addPixmap(thumb_pixmap)
         self.window.photo_view.setScene(scene)
 
     def set_data_root_path(self, path: str):
@@ -128,13 +126,13 @@ class MainWindow:
 
         if image_file_paths:
             model = QFileSystemModel()
-            model.setFilter(QDir.Files)
+            model.setFilter(QDir.Filter.Files)
             model.setNameFilters(('*.arw',))
             model.setNameFilterDisables(False)
             model.setRootPath(QDir.rootPath())
             model.setIconProvider(RawIconProvider())
-            self.window.thumbnail_list_view.setViewMode(QListView.IconMode)
-            self.window.thumbnail_list_view.setLayoutMode(QListView.Batched)
+            self.window.thumbnail_list_view.setViewMode(QListView.ViewMode.IconMode)
+            self.window.thumbnail_list_view.setLayoutMode(QListView.LayoutMode.Batched)
             self.window.thumbnail_list_view.setBatchSize(20)
             self.window.thumbnail_list_view.setModel(model)
             self.window.thumbnail_list_view.setRootIndex(model.index(str(self.data_root_path)))
